Usage: inventaire_obs.py [OPTIONS]

Options:

  --help               Show this message and exit.
  
  -n, --name TEXT      Nom de code du magasin  [required]
  
  -f, --fichier TEXT   Nom du fichier avec les IPs  [required] // Une IP par ligne
  
  -s, --sortie TEXT    Nom du fichier de sortie
  
  -u, --username TEXT  Username  [required]
  
  -p, --password TEXT  Password
  